package com.yiqi.core.mapper;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.dto.GoodsSkuDTO;
import com.yiqi.core.domain.vo.GoodsSkuQueryVO;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.GoodsSku;
import org.apache.ibatis.annotations.Param;

/**
 * 物料明细Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-21
 */
public interface GoodsSkuMapper extends BaseMapper<GoodsSku> {
    /**
     * 查询物料明细
     *
     * @param id 物料明细主键
     * @return 物料明细
     */
    public GoodsSku selectGoodsSkuById(Long id);

    /**
     * 查询物料明细列表
     *
     * @param goodsSku 物料明细
     * @return 物料明细集合
     */
    public List<GoodsSku> selectGoodsSkuList(GoodsSku goodsSku);

    /**
     * 查询物料明细列表(总部)
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);

    /**
     * 新增物料明细
     *
     * @param goodsSku 物料明细
     * @return 结果
     */
    public int insertGoodsSku(GoodsSku goodsSku);

    /**
     * 修改物料明细
     *
     * @param goodsSku 物料明细
     * @return 结果
     */
    public int updateGoodsSku(GoodsSku goodsSku);

    /**
     * 删除物料明细
     *
     * @param id 物料明细主键
     * @return 结果
     */
    public int deleteGoodsSkuById(Long id);

    /**
     * 批量删除物料明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGoodsSkuByIds(Long[] ids);


    /**
     * 查询物料明细列表  -总部查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表 -工厂查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表 -门店查商品进货
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectPurchaseGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);




    /**
     * 查询物料明细列表- 总部查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByHq(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表  工厂查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByFactory(GoodsSkuDTO goodsSkuDTO);

    /**
     * 查询物料明细列表  门店查零售
     *
     * @param goodsSkuDTO 物料明细对象
     * @return 物料明细集合
     */
    public List<GoodsSkuQueryVO> selectRetailGoodsSkuInfoByStore(GoodsSkuDTO goodsSkuDTO);


    /**
     * 查询商品sku数量
     *
     * @param goodsId 商品id
     * @return 结果
     */
    public Long getGoodsSkuNumsByGoodsId(@Param("goodsId") Long goodsId);

    /**
     *
     * @param id
     * @return
     */
    List<GoodsSku> selectGoodsSkuListByGoodsId(@Param("goodsId") Long goodsId);

    /**
     * 查询商品sku最小销售价
     *
     * @param goodsIds   商品id
     * @param storeId      机构id
     * @return 结果
     */
    @MapKey("goodsId")
    Map<Long, Map<String, Object>> selectStoreSkuMinSalePriceToGoodsRetail(@Param("goodsIds") List<Long> goodsIds, @Param("storeId") Long storeId);

    /**
     * 平台减库存，保证库存不小于0
     *
     * @param skuId
     * @param buyNum
     * @return
     */
    int minusGoodsSkuStockByHq(@Param("skuId") Long skuId, @Param("buyNum") Integer buyNum);


    /**
     * 平台减库存，保证库存不小于0
     *
     * @param skuId
     * @param buyNum
     * @return
     */
    int addGoodsSkuStockByHq(@Param("skuId") Long skuId, @Param("buyNum") Integer buyNum);


    /**
     * 平台减库存，线下扣款允许超卖的情况，因此不校验库存是否不足
     *
     * @param skuId
     * @param buyNum
     * @return
     */
    int minusGoodsSkuStockNotCheckByHq(@Param("skuId") Long skuId, @Param("buyNum") Integer buyNum);

}
