package com.yiqi.core.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.settlement.domain.dto.StoreChargeStatistics;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.SettlementStoreStatistics;
import org.apache.ibatis.annotations.Param;

/**
 * 门店每日统计Mapper接口
 *
 * @author douya
 * @date 2025-03-21
 */
public interface SettlementStoreStatisticsMapper extends BaseMapper<SettlementStoreStatistics> {

    /**
     * 查询门店每日统计列表
     *
     * @param settlementStoreStatistics 门店每日统计
     * @return 门店每日统计集合
     */
    public List<SettlementStoreStatistics> selectSettlementStoreStatisticsList(SettlementStoreStatistics settlementStoreStatistics);

    /**
     * 删除门店每日统计
     *
     * @param id 门店每日统计主键
     * @return 结果
     */
    public int deleteSettlementStoreStatisticsById(Long id);

    /**
     * 批量删除门店每日统计
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSettlementStoreStatisticsByIds(Long[] ids);


    /**
     * 查询订单统计
     *
     * @param storeId 门店id
     * @return 结果
     */
    StoreChargeStatistics chargeTotal(@Param("storeId") Long storeId);

    /**
     * 查询订单统计
     *
     * @param startDay 开始日期
     * @param endDay   结束日期
     * @return 结果
     */
    List<SettlementStoreStatistics> totalByDate(@Param("startDay") Integer startDay, @Param("endDay") Integer endDay);

    /**
     * 查询订单统计
     *
     * @param startDay 开始日期
     * @param endDay   结束日期
     * @return 结果
     */
    List<SettlementStoreStatistics> totalByStore(@Param("startDay") Integer startDay, @Param("endDay") Integer endDay);

    /**
     * 查询订单统计
     *
     * @param storeId 门店id
     * @param startDay 开始日期
     * @param endDay   结束日期
     * @return 结果
     */
    SettlementStoreStatistics orderStatistics(@Param("storeId") Long storeId, @Param("startDay") Integer startDay, @Param("endDay") Integer endDay);
}
