package com.yiqi.system.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.system.mapper.SysDataGroupInfoMapper;
import com.yiqi.system.domain.SysDataGroupInfo;
import com.yiqi.system.service.ISysDataGroupInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 组合数据详情Service业务层处理
 *
 * @author douya
 * @date 2024-10-29
 */
@Service
public class SysDataGroupInfoServiceImpl extends ServiceImpl<SysDataGroupInfoMapper, SysDataGroupInfo> implements ISysDataGroupInfoService {

    //<editor-folder desc="基础韩素">

    /**
     * 查询组合数据详情
     *
     * @param id 组合数据详情主键
     * @return 组合数据详情
     */
    @Override
    public SysDataGroupInfo selectSysDataGroupInfoById(Integer id) {
        return baseMapper.selectSysDataGroupInfoById(id);
    }

    /**
     * 查询组合数据详情列表
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 组合数据详情
     */
    @Override
    public List<SysDataGroupInfo> selectSysDataGroupInfoList(SysDataGroupInfo sysDataGroupInfo) {
        return baseMapper.selectSysDataGroupInfoList(sysDataGroupInfo);
    }

    /**
     * 新增组合数据详情
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    @Override
    public int insertSysDataGroupInfo(SysDataGroupInfo sysDataGroupInfo) {
        return baseMapper.insert(sysDataGroupInfo);
    }

    /**
     * 修改组合数据详情
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    @Override
    public int updateSysDataGroupInfo(SysDataGroupInfo sysDataGroupInfo) {
        return baseMapper.updateById(sysDataGroupInfo);
    }

    /**
     * 批量删除组合数据详情
     *
     * @param ids 需要删除的组合数据详情主键
     * @return 结果
     */
    @Override
    public int deleteSysDataGroupInfoByIds(Integer[] ids) {
        return baseMapper.deleteSysDataGroupInfoByIds(ids);
    }

    /**
     * 删除组合数据详情信息
     *
     * @param id 组合数据详情主键
     * @return 结果
     */
    @Override
    public int deleteSysDataGroupInfoById(Integer id) {
        return baseMapper.deleteSysDataGroupInfoById(id);
    }

    /**
     * 修改组合数据详情状态
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    @Override
    public int updateSysDataGroupInfoStatus(SysDataGroupInfo sysDataGroupInfo) {
        return baseMapper.updateSysDataGroupInfo(sysDataGroupInfo);
    }

    @Override
    public List<SysDataGroupInfo> getDataList(Integer gid, Integer status) {
        QueryWrapper<SysDataGroupInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("gid", gid);
        if (status != null) {
            wrapper.eq("status", status);
        }
        wrapper.orderByDesc("sort");
        return baseMapper.selectList(wrapper);
    }
}
